@@ -1,4 +1,4 @@
-### R code from vignette source 'NMOFdist.Rnw'
+### R code from vignette source '/home/es/Packages/NMOF/reports/NMOFdist/NMOFdist.Rnw'
 
 ###################################################
 ### code chunk number 1: NMOFdist.Rnw:77-78
@@ -7,69 +7,62 @@ options(continue = " ", digits = 3, width = 65)
 
 
 ###################################################
-### code chunk number 2: NMOFdist.Rnw:108-110 (eval = FALSE)
+### code chunk number 2: NMOFdist.Rnw:111-113 (eval = FALSE)
 ###################################################
 ## install.packages("NMOF") ## CRAN
-## install.packages("NMOF", repos = "http://R-Forge.R-project.org")
+## install.packages("NMOF", repos = "http://enricoschumann.net/R")
 
 
 ###################################################
-### code chunk number 3: NMOFdist.Rnw:115-118
+### code chunk number 3: NMOFdist.Rnw:117-120
 ###################################################
 require("NMOF")
 set.seed(1122344)
-nC <- 2L ## the number of cores to be used
+nC <- 4L ## the number of cores to be used
 
 
 ###################################################
-### code chunk number 4: NMOFdist.Rnw:124-127
+### code chunk number 4: NMOFdist.Rnw:126-128
 ###################################################
 require("rbenchmark")
 require("parallel")
-require("snow")
 
 
 ###################################################
-### code chunk number 5: NMOFdist.Rnw:134-135
-###################################################
-require("rlecuyer")
-
-
-###################################################
-### code chunk number 6: NMOFdist.Rnw:142-144 (eval = FALSE)
+### code chunk number 5: NMOFdist.Rnw:134-136 (eval = FALSE)
 ###################################################
 ## whereToLook <- system.file("NMOFex/NMOFdist.R", package = "NMOF")
 ## file.show(whereToLook, title = "NMOF examples")
 
 
 ###################################################
-### code chunk number 7: NMOFdist.Rnw:157-166
+### code chunk number 6: NMOFdist.Rnw:148-157
 ###################################################
 testFun <- function(ignore, delay) {
     Sys.sleep(delay)
     1
 }
  
-delay <- 0.01     ## running time of function
+delay <- 0.05     ## running time of function
 n <- 8            ## how many calls per lapply
 repl <- 10        ## how many restarts
 sq <- seq_len(n)
 
 
 ###################################################
-### code chunk number 8: NMOFdist.Rnw:172-179
+### code chunk number 7: NMOFdist.Rnw:161-168
 ###################################################
 cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
 benchmark(lapply(sq, testFun, delay),                ## serial
-          mclapply(sq, testFun, delay),              ## package 'parallel'
-          clusterApply(cl, sq, testFun, delay),      ## package 'snow'
+          mclapply(sq, testFun, delay),              ## formerly 'multicore'
+          clusterApply(cl, sq, testFun, delay),      ## formerly 'snow'
           columns = c("test", "elapsed", "relative"),
           order = "relative", replications = repl)
 stopCluster(cl)
 
 
 ###################################################
-### code chunk number 9: NMOFdist.Rnw:188-192
+### code chunk number 8: NMOFdist.Rnw:176-180
 ###################################################
 OF <- function(b, X, y) {
     temp <- X %*% b - y
@@ -78,22 +71,22 @@ OF <- function(b, X, y) {
 
 
 ###################################################
-### code chunk number 10: NMOFdist.Rnw:198-202
+### code chunk number 9: NMOFdist.Rnw:187-191
 ###################################################
 ncol <- 10; nrow <- 200
-X <- array(rnorm(nrow*ncol), dim= c(nrow,ncol))
+X <- array(rnorm(nrow * ncol), dim = c(nrow, ncol))
 y <- rnorm(nrow)
 b <- rnorm(ncol)
 
 
 ###################################################
-### code chunk number 11: NMOFdist.Rnw:206-207
+### code chunk number 10: NMOFdist.Rnw:195-196
 ###################################################
 OF(b, X, y)
 
 
 ###################################################
-### code chunk number 12: NMOFdist.Rnw:212-217
+### code chunk number 11: NMOFdist.Rnw:201-206
 ###################################################
 n <- 50            ## how many calls per lapply
 sq <- seq_len(n)
@@ -103,7 +96,7 @@ for (i in sq)
 
 
 ###################################################
-### code chunk number 13: NMOFdist.Rnw:222-246
+### code chunk number 12: NMOFdist.Rnw:210-234
 ###################################################
 snow_with_copying <- expression({
     ignore1 <- clusterApply(cl, lP, OF, X, y)  
@@ -119,7 +112,7 @@ snow_without_copying <- expression({
         sum(temp^2)
     }
     ignore3 <- clusterApply(cl, lP, OF1)
-    })
+})
 
 cl <- makeCluster(rep("localhost", nC), type = "SOCK")
 clusterExport(cl, list("X", "y"))
@@ -132,14 +125,14 @@ stopCluster(cl)
 
 
 ###################################################
-### code chunk number 14: NMOFdist.Rnw:251-253
+### code chunk number 13: NMOFdist.Rnw:241-243
 ###################################################
 all.equal(ignore1, ignore2)
 all.equal(ignore2, ignore3)
 
 
 ###################################################
-### code chunk number 15: NMOFdist.Rnw:262-288
+### code chunk number 14: NMOFdist.Rnw:252-278
 ###################################################
 testFun <- function(x) {
     Sys.sleep(0.1)
@@ -148,20 +141,20 @@ testFun <- function(x) {
 with_loop <- expression(
     sol1 <- bracketing(testFun,
                        interval = c(0.3, 0.9),
-                       n = 100L)
-    )
+                       n = 100L))
+
 with_multicore <- expression(
     sol2 <- bracketing(testFun,
                        interval = c(0.3, 0.9),
                        n = 100L,
                        method = "multicore", 
-                       mc.control = list(mc.cores = nC))
-    )
+                       mc.control = list(mc.cores = nC)))
+
 with_snow  <- expression(
     sol3 <- bracketing(testFun,
                        interval = c(0.3, 0.9),
-                       n = 100L, method = "snow", cl = nC)
-    )
+                       n = 100L, method = "snow", cl = nC))
+
 benchmark(with_loop, 
           with_multicore, 
           with_snow,
@@ -170,36 +163,36 @@ benchmark(with_loop,
 
 
 ###################################################
-### code chunk number 16: NMOFdist.Rnw:292-294
+### code chunk number 15: NMOFdist.Rnw:282-284
 ###################################################
 all.equal(sol1, sol2)
 all.equal(sol1, sol3)
 
 
 ###################################################
-### code chunk number 17: NMOFdist.Rnw:304-307
+### code chunk number 16: NMOFdist.Rnw:294-297
 ###################################################
 ncol <- 20
-nrow <- 100
+nrow <- 1000
 P <- array(rnorm(nrow * ncol), dim = c(nrow, ncol))
 
 
 ###################################################
-### code chunk number 18: NMOFdist.Rnw:313-315
+### code chunk number 17: NMOFdist.Rnw:304-306
 ###################################################
 fun <- function (x, h)
     sort(x, partial = h)[h]
 
 
 ###################################################
-### code chunk number 19: NMOFdist.Rnw:319-321
+### code chunk number 18: NMOFdist.Rnw:310-312
 ###################################################
 h <- 5L
 fun(P[ ,1L], h)
 
 
 ###################################################
-### code chunk number 20: NMOFdist.Rnw:329-336
+### code chunk number 19: NMOFdist.Rnw:320-327
 ###################################################
 loopfun <- function(x, f, ...) {
     ns <- ncol(x)
@@ -211,17 +204,18 @@ loopfun <- function(x, f, ...) {
 
 
 ###################################################
-### code chunk number 21: NMOFdist.Rnw:341-342
+### code chunk number 20: NMOFdist.Rnw:332-333
 ###################################################
 loopresult <- loopfun(P, fun, h)
 
 
 ###################################################
-### code chunk number 22: NMOFdist.Rnw:352-359
+### code chunk number 21: NMOFdist.Rnw:343-351
 ###################################################
 mat2list <- function(x) {
-    listP <- vector(mode = "list", length = ncol(x))
-    for (s in seq_len(ncol(P)))
+    nx <- ncol(x)
+    listP <- vector(mode = "list", length = nx)
+    for (s in seq_len(nx))
         listP[[s]] <- P[ ,s]
     listP
 }
@@ -229,7 +223,7 @@ listP <- mat2list(P)
 
 
 ###################################################
-### code chunk number 23: NMOFdist.Rnw:366-370
+### code chunk number 22: NMOFdist.Rnw:358-362
 ###################################################
 cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
 snowresult <- unlist(clusterApply(cl, listP, fun, h))
@@ -238,7 +232,7 @@ all.equal(loopresult, snowresult)
 
 
 ###################################################
-### code chunk number 24: NMOFdist.Rnw:375-381
+### code chunk number 23: NMOFdist.Rnw:367-373
 ###################################################
 cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
 benchmark(clusterApply(cl, listP, fun, h),
@@ -249,23 +243,23 @@ stopCluster(cl)
 
 
 ###################################################
-### code chunk number 25: NMOFdist.Rnw:387-392
+### code chunk number 24: NMOFdist.Rnw:383-388
 ###################################################
-ncol <- 200
-nrow <- 200
+ncol <- 100
+nrow <- 1000
 P <- array(rnorm(nrow * ncol), dim = c(nrow, ncol))
 
 system.time(for (i in seq_len(10000L)) fun(P[ ,1L], 10L))
 
 
 ###################################################
-### code chunk number 26: NMOFdist.Rnw:396-397
+### code chunk number 25: NMOFdist.Rnw:392-393
 ###################################################
 d <- round(ncol/nC) ## nC is the number of cores
 
 
 ###################################################
-### code chunk number 27: NMOFdist.Rnw:401-404
+### code chunk number 26: NMOFdist.Rnw:396-399
 ###################################################
 listP <- vector(mode = "list", length = nC)
 for (s in seq_len(nC))
@@ -273,19 +267,19 @@ for (s in seq_len(nC))
 
 
 ###################################################
-### code chunk number 28: NMOFdist.Rnw:408-415
+### code chunk number 27: NMOFdist.Rnw:403-410
 ###################################################
 cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
-benchmark(snowresult <- clusterApply(cl, listP, loopfun, fun, h),
-          loopresult <- loopfun(P, fun, h),
+benchmark(parallel.result <- clusterApply(cl, listP, loopfun, fun, h),
+          loop.result <- loopfun(P, fun, h),
           columns = c("test", "elapsed", "relative"),
           order = "relative", replications = 100)
 stopCluster(cl)
-all.equal(loopresult, unlist(snowresult))
+all.equal(loop.result, unlist(parallel.result))
 
 
 ###################################################
-### code chunk number 29: NMOFdist.Rnw:427-449
+### code chunk number 28: NMOFdist.Rnw:427-449
 ###################################################
 OF <- function(x, y) {
     Sys.sleep(0.001)
@@ -299,7 +293,7 @@ with_loop <- list(nB = size, nP = 200L, nG = 50L, prob = 0.002,
 with_snow <- list(nB = size, nP = 200L, nG = 50L, prob = 0.002,
                   printBar = FALSE, printDetail = FALSE,
                   methodOF = "snow", cl = nC)
-with_multicore <- list(nB = size, nP = 20L, nG = 100L, prob = 0.002,
+with_multicore <- list(nB = size, nP = 200L, nG = 50L, prob = 0.002,
                        printBar = FALSE, printDetail = FALSE,
                        methodOF = "multicore")
 
@@ -312,14 +306,18 @@ benchmark(GAopt(OF, algo = with_loop, y = y),
 
 
 ###################################################
-### code chunk number 30: NMOFdist.Rnw:457-459
+### code chunk number 29: NMOFdist.Rnw:457-463
 ###################################################
 with_multicore$mc.control <- list(mc.cores = 1L)
-system.time(GAopt(OF, algo = with_multicore, y = y))
+## system.time(GAopt(OF, algo = with_multicore, y = y))
+benchmark(GAopt(OF, algo = with_loop, y = y),
+          GAopt(OF, algo = with_multicore, y = y),
+          columns = c("test", "elapsed", "relative"),
+          order = "relative", replications = 1)
 
 
 ###################################################
-### code chunk number 31: NMOFdist.Rnw:463-479
+### code chunk number 30: NMOFdist.Rnw:467-483
 ###################################################
 OF <- function(x, y) {
     Sys.sleep(0.01)
@@ -340,17 +338,17 @@ all.equal(sol$OFvalue, 0)
 
 
 ###################################################
-### code chunk number 32: NMOFdist.Rnw:483-484
+### code chunk number 31: NMOFdist.Rnw:487-488
 ###################################################
-round(t1[[3L]]/t2[[3L]])
+round(t1[[3L]]/t2[[3L]],1)
 
 
 ###################################################
-### code chunk number 33: NMOFdist.Rnw:488-506
+### code chunk number 32: NMOFdist.Rnw:492-510
 ###################################################
 OF <- function(x, y, k) {
     Sys.sleep(0.01)
-    sum(x != y)+k
+    sum(x != y) + k
 }
 size <- 10L; y <- runif(size) > 0.5; k <- 10
 algo <- list(nB = size, nP = 20L, nG = 100L, prob = 0.002,
@@ -369,7 +367,7 @@ all.equal(sol$OFvalue, k)
 
 
 ###################################################
-### code chunk number 34: NMOFdist.Rnw:511-541
+### code chunk number 33: NMOFdist.Rnw:516-545
 ###################################################
 testFun  <- function(x) {
     Sys.sleep(0.1)
@@ -379,21 +377,20 @@ lower <- 1:2; upper <- 5; n <- 10
 with_loop <- expression(
     sol1 <- gridSearch(fun = testFun,
                        lower = lower, upper = upper,
-                       n = n, printDetail = FALSE)
-                )
+                       n = n, printDetail = FALSE))
+
 with_multicore <- expression(
     sol2 <- gridSearch(fun = testFun,
                        lower = lower, upper = upper,
                        n = n, printDetail = FALSE,
-                       method = "multicore")
-    )
+                       method = "multicore"))
+
 with_snow <- expression(
     sol3 <- gridSearch(fun = testFun,
                        lower = lower, upper = upper,
                        n = n, printDetail = FALSE,
                        method = "snow",
-                       cl = nC)
-    )
+                       cl = nC))
 
 benchmark(with_loop, with_multicore, with_snow,
           columns = c("test", "elapsed", "relative"),
@@ -404,7 +401,7 @@ all.equal(sol3$minlevels, 1:2)
 
 
 ###################################################
-### code chunk number 35: NMOFdist.Rnw:546-565
+### code chunk number 34: NMOFdist.Rnw:550-569
 ###################################################
 testFun  <- function(x, k) {
     Sys.sleep(0.1)
@@ -428,7 +425,7 @@ all.equal(sol3$minlevels, 1:2)
 
 
 ###################################################
-### code chunk number 36: NMOFdist.Rnw:571-590
+### code chunk number 35: NMOFdist.Rnw:575-594
 ###################################################
 testFun  <- function(x) {
     Sys.sleep(0.1)
@@ -452,33 +449,10 @@ all.equal(sol2$values, temp)
 
 
 ###################################################
-### code chunk number 37: NMOFdist.Rnw:597-615 (eval = FALSE)
-###################################################
-## cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
-## clusterSetupSPRNG(cl, seed = rep.int(12345, nC))
-## sol3 <- gridSearch(fun = testFun,
-##                    lower = lower, upper = upper,
-##                    n = n, printDetail = FALSE,
-##                    method = "snow", cl = cl)
-## stopCluster(cl)
-## temp <- sol3$values
-## 
-## ## ... and again
-## cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
-## clusterSetupSPRNG(cl, seed = rep.int(12345, nC))
-## sol3 <- gridSearch(fun = testFun,
-##                    lower = lower, upper = upper,
-##                    n = n, printDetail = FALSE,
-##                    method = "snow", cl = cl)
-## stopCluster(cl)
-## all.equal(sol3$values, temp)
-
-
-###################################################
-### code chunk number 38: NMOFdist.Rnw:619-635
+### code chunk number 36: NMOFdist.Rnw:599-615
 ###################################################
 cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
-clusterSetupRNGstream(cl, seed = rep.int(2222, 6))
+clusterSetRNGStream(cl, 2222)
 sol3 <- gridSearch(fun = testFun, lower = lower, upper = upper,
                    n = n, printDetail = FALSE,
                    method = "snow", cl = cl)
@@ -487,7 +461,7 @@ temp <- sol3$values
 
 ## ... and again
 cl <- makeCluster(c(rep("localhost", nC)), type = "SOCK")
-clusterSetupRNGstream (cl, seed = rep.int(2222, 6))
+clusterSetRNGStream (cl, 2222)
 sol3 <- gridSearch(fun = testFun, lower = lower, upper = upper,
                    n = n, printDetail = FALSE,
                    method = "snow", cl = cl)
@@ -496,7 +470,7 @@ all.equal(sol3$values, temp)
 
 
 ###################################################
-### code chunk number 39: NMOFdist.Rnw:643-655
+### code chunk number 37: NMOFdist.Rnw:623-635
 ###################################################
 xTRUE <- runif(5L)
 data <- list(xTRUE = xTRUE,  ## the TRUE solution
@@ -513,22 +487,22 @@ algo <- list(q = 0.05, nS = 200L, nT = 10L,
 
 
 ###################################################
-### code chunk number 40: NMOFdist.Rnw:658-678
+### code chunk number 38: NMOFdist.Rnw:638-658
 ###################################################
 with_loop <- expression(
     sols1 <- restartOpt(fun = TAopt, n = 100L,
-                        OF = OF, algo = algo, data = data)
-    )
+                        OF = OF, algo = algo, data = data))
+
 with_multicore <- expression(
     sols2 <- restartOpt(fun = TAopt, n = 100L,
                         OF = OF, algo = algo, data = data,
-                        method = "multicore")
-                )
+                        method = "multicore"))
+
 with_snow <- expression(
     sols3 <- restartOpt(fun = TAopt, n = 100L,
                         OF = OF, algo = algo, data = data,
-                        method = "snow", cl = nC)
-    )
+                        method = "snow", cl = nC))
+
 benchmark(with_loop, with_multicore, with_snow,
           columns = c("test", "elapsed", "relative"),
           order = "relative", replications = 1)
@@ -538,7 +512,7 @@ all.equal(length(sols3), 100L)
 
 
 ###################################################
-### code chunk number 41: NMOFdist.Rnw:705-706
+### code chunk number 39: NMOFdist.Rnw:685-686
 ###################################################
 toLatex(sessionInfo())
 
